@@ -3,7 +3,7 @@ import click
 from apigee import console
 from apigee.auth import common_auth_options, gen_auth
 from apigee.backups.backups import Backups
-from apigee.cls import OptionEatAll
+# from apigee.cls import OptionEatAll
 from apigee.prefix import common_prefix_options
 from apigee.silent import common_silent_options
 from apigee.verbose import common_verbose_options
@@ -41,14 +41,14 @@ def _take_snapshot(
 ):
     if not isinstance(apis, set):
         apis = set(apis)
-    return Backups(
+    Backups(
         gen_auth(username, password, mfa_secret, token, zonename),
         org,
         target_directory,
         prefix=prefix,
         fs_write=True,
         apis=apis,
-        environments=environments,
+        environments=list(environments),
     ).take_snapshot()
 
 
@@ -72,8 +72,11 @@ def _take_snapshot(
     show_default=True,
 )
 # @click.option('--apis', metavar='LIST', cls=OptionEatAll, default=APIS_CHOICES, show_default=True, help='')
+# @click.option(
+#     '-e', '--environments', metavar='LIST', cls=OptionEatAll, default=['test', 'prod'], help=''
+# )
 @click.option(
-    '-e', '--environments', metavar='LIST', cls=OptionEatAll, default=['test', 'prod'], help=''
+    '-e', '--environments', multiple=True, show_default=True, default=['test', 'prod'], help=''
 )
 def take_snapshot(*args, **kwargs):
     _take_snapshot(*args, **kwargs)
