@@ -1,11 +1,12 @@
+import builtins
 import functools
 import inspect
 import json
 import logging
 import sys
 
-from apigee import APIGEE_CLI_EXCEPTION_LOG_FILE, console
-from apigee.utils import touch
+from apigee import APIGEE_CLI_EXCEPTIONS_LOG_FILE, console
+from apigee.utils import remove_file_above_size, touch
 
 
 class InvalidApisError(Exception):
@@ -16,6 +17,16 @@ class NotYetImplementedError(Exception):
     pass
 
 
+def setup_global_logger():
+    remove_file_above_size(APIGEE_CLI_EXCEPTIONS_LOG_FILE, size_kb=1000)
+    f_handler = logging.FileHandler(APIGEE_CLI_EXCEPTIONS_LOG_FILE)
+    f_handler.setLevel(logging.WARNING)
+    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+    f_handler.setFormatter(formatter)
+    logging.getLogger("").addHandler(f_handler)
+    # logging.StreamHandler(stream=None)
+
+
 def exception_handler(func):
     @functools.wraps(func)
     def wrapper(*args, **kwargs):
@@ -23,12 +34,6 @@ def exception_handler(func):
             result = func(*args, **kwargs)
             return result
         except Exception as e:
-            touch(APIGEE_CLI_EXCEPTION_LOG_FILE)
-            f_handler = logging.FileHandler(APIGEE_CLI_EXCEPTION_LOG_FILE, 'w+')
-            f_handler.setLevel(logging.INFO)
-            formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-            f_handler.setFormatter(formatter)
-            logging.getLogger("").addHandler(f_handler)
             logging.error('Exception occurred', exc_info=True)
             frm = inspect.trace()[-1]
             mod = inspect.getmodule(frm[0])
