@@ -29,13 +29,23 @@ def common_prefix_options(func):
         prefix = profile_dict['prefix']
     except KeyError:
         pass
-    return click.option('--prefix', help='team/resource prefix filter', default=prefix, show_default=True)(func)
+    return click.option(
+        '--prefix', help='team/resource prefix filter', default=prefix, show_default=True
+    )(func)
 
 
-def auth_with_prefix(auth_obj, org, name, attribute_name=APIGEE_CLI_AUTHORIZATION_DEVELOPER_ATTRIBUTE):
-    team = Developers(auth_obj, org, auth_obj.username).get_developer_attribute(attribute_name).json()['value']
+def auth_with_prefix(
+    auth_obj, org, name, attribute_name=APIGEE_CLI_AUTHORIZATION_DEVELOPER_ATTRIBUTE
+):
+    team = (
+        Developers(auth_obj, org, auth_obj.username)
+        .get_developer_attribute(attribute_name)
+        .json()['value']
+    )
     allowed = team.split(',')
     for prefix in allowed:
         if name.startswith(prefix):
             return name
-    raise Exception(f'401 Client Error: Unauthorized for team: {str(allowed)}\nAttempted to access resource: {name}')
+    raise Exception(
+        f'401 Client Error: Unauthorized for team: {str(allowed)}\nAttempted to access resource: {name}'
+    )
